#include <stdio.h>
#include <string.h>
#include "cxio.h"

void
usage (void)
{
  printf ("Usage: cxcrypt [-e|-d] <infile> <outfile> <password>\n");
}

int
main (int argc, char *argv[])
{
  enum { OP_ENCRYPT, OP_DECRYPT, NUM_OPS };
  struct cx_file *fpo, *fpi;
  int mode;
  char *password = NULL;
  char *infile = NULL;
  char *outfile = NULL;
  char buf[256];
  int nread = 0;
  int nwritten = 0;

  if (argc != 5)
    {
      usage ();
      return 1;
    }

  if (strcmp(argv[1], "-e") == 0)
    {
      mode = OP_ENCRYPT;
    }
  else if (strcmp(argv[1], "-d") == 0)
    {
      mode = OP_DECRYPT;
    }
  else
    {
      usage ();
      return 1;
    }

  infile = argv[2];
  outfile = argv[3];
  password = argv[4];

  if ((fpo = cx_fopen (outfile, "w")) == NULL)
    {
      perror ("opening output file");
      return 1;
    }

  if ((fpi = cx_fopen (infile, "r")) == NULL)
    {
      perror ("opening input file");
      return 1;
    }

  cx_setkey (password, mode == OP_ENCRYPT? fpo: fpi);

  while (nread == nwritten && !cx_feof(fpi))
    {
      nwritten = 0;
      if ((nread = (int)cx_fread(buf, 1, sizeof buf, fpi)) > 0)
	{
	  nwritten = (int)cx_fwrite(buf, 1, nread, fpo);
	}
    }

  (void)cx_fclose(fpi);
  (void)cx_fclose(fpo);

  if (nwritten != nread)
    {
      fprintf (stderr, "Error, only wrote %d bytes instead of %d\n", nwritten, nread);
      return 2;
    }

  return 0;
}
